developerscripttools.PyTestScript
=================================

.. abjad-lineage:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript

.. autoclass:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.alias
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.argument_parser
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.formatted_help
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.formatted_usage
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.formatted_version
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.long_description
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.process_args
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.program_name
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.scripting_group
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.setup_argument_parser
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.short_description
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.version
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__call__
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__eq__
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__ne__
      ~abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__repr__

Bases
-----

- :py:class:`developerscripttools.DirectoryScript <abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript>`

- :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.setup_argument_parser
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__repr__
   :noindex:
